@@ -7,14 +7,22 @@ use HTTP::Request;
 use Net::DAV::Server;
 use Filesys::Virtual::Plain;
 
-use Plack::Util::Accessor qw(root);
+use Plack::Util::Accessor qw(root dbobj);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub prepare_app {
     my $self = shift;
+
+    my ($classname, $args) = ref($self->dbobj) ?  
+        @{$self->dbobj} : 
+        $self->dbobj || 'Simple';
+    my $class = Plack::Util::load_class($classname, 'Net::DAV::LockManager')
+        or die 'could not load LockManager class';
+
     $self->{dav} = Net::DAV::Server->new(
-        -filesys => Filesys::Virtual::Plain->new({root_path => $self->root || '.'})
+        -filesys => Filesys::Virtual::Plain->new({root_path => $self->root || '.'}),
+        -dbobj => $class->new($args),
     );
 }
 
@@ -51,6 +59,33 @@ Plack::App::DAV - simple DAV server for Plack
 
 Plack::App::DAV is simple DAV server for Plack.
 
+=head1 CONFIGURATION
+
+=over 4
+
+=item root
+
+Document root directory. Defaults to the current directory.
+
+=item dbobj
+
+class specification and instanciate arguments for Net::DAV::LockManager.
+Defaults to 'Simple', makes Net::DAV::LockManager::Simple instance.
+
+  my $app = Plack::App::DAV->new;
+
+is identical to the below.
+
+  my $app = Plack::App::DAV->new(dbobj => 'Simple');
+
+To make LockManager with sqlite DB, write
+
+  my $app = Plack::App::DAV->new(
+      dbobj => [DB => 'dbi:sqlite:lockdb.sqlite3']
+  );
+
+=back
+
 =head1 AUTHOR
 
 Nobuo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
